using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Windows.Forms;
using System.Globalization;

using SwissAcademic.Citavi;
using SwissAcademic.Citavi.Metadata;
using SwissAcademic.Citavi.Shell;
using SwissAcademic.Collections;

// Implementation of macro editor is preliminary and experimental.
// The Citavi object model is subject to change in future version.

public static class CitaviMacro
{
	public static void Main()
	{
		//Change date format from dd-MMM-yyyy to dd.MM.yyyy
		if (Program.ProjectShells.Count == 0) return;		//no project open	
		if (IsBackupAvailable() == false) return;			//user wants to backup his/her project first	
		
		List<Reference> references = Program.ActiveProjectShell.PrimaryMainForm.GetFilteredReferences();
		if (references == null || references.Count == 0) return;
		
		int counter = 0;
		
		CultureInfo[] cultures = new CultureInfo[] {
			CultureInfo.GetCultureInfo("en-US"),
			CultureInfo.GetCultureInfo("de-DE"),
			CultureInfo.GetCultureInfo("es-ES"),
			CultureInfo.GetCultureInfo("pt-BR"),
			CultureInfo.GetCultureInfo("fr-FR"),
			CultureInfo.GetCultureInfo("pl-PL")
		};
		
		string[] formatsToSearchFor = new string[] { "dd-MMM-yy", "dd-MMM-yyyy" };
		
		
		foreach (Reference reference in references)
		{
			if (string.IsNullOrEmpty(reference.AccessDate)) continue;
			DateTime dateFound = DateTime.MinValue;

			foreach (CultureInfo culture in cultures)
			{
				if (DateTime.TryParseExact(reference.AccessDate, formatsToSearchFor, culture, DateTimeStyles.None, out dateFound))
				{
					reference.AccessDate = dateFound.ToString("d", culture); //"d" is NOT a day, but the standard date format specifier for the various cultures, e.g. 24.12.2014 for german christmas eve
					counter++;
					break;
				}
			}
		}
		
		string message = "{0} dates were changed to standard format"; 
		
		message = string.Format(message, counter);
		MessageBox.Show(message, "Macro", MessageBoxButtons.OK, MessageBoxIcon.Information); 
	}
	
	
	private static bool IsBackupAvailable() 
	{
		string warning = String.Concat("Important: This macro will make irreversible changes to your project.",
			"\r\n\r\n", "Make sure you have a current backup of your project before you run this macro.",
			"\r\n", "If you aren't sure, click Cancel and then, in the main Citavi window, on the File menu, click Create backup.",
			"\r\n\r\n", "Do you want to continue?"
		);
				
		
		return (MessageBox.Show(warning, "Citavi", MessageBoxButtons.OKCancel, MessageBoxIcon.Exclamation, MessageBoxDefaultButton.Button2) == DialogResult.OK);


	} //end IsBackupAvailable()
}